@@ -49,6 +49,15 @@ impl<'a> RTPBuffer<'a, Readable> {
             }
         }
     }
+
+    pub unsafe fn from_glib_borrow<'b>(
+        rtp_buffer: *mut ffi::GstRTPBuffer,
+    ) -> glib::translate::Borrowed<RTPBuffer<'b, Readable>> {
+        glib::translate::Borrowed::new(RTPBuffer {
+            rtp_buffer: *rtp_buffer,
+            phantom: PhantomData,
+        })
+    }
 }
 
 impl<'a> RTPBuffer<'a, Writable> {
@@ -295,6 +304,29 @@ impl<'a, T> RTPBuffer<'a, T> {
         }
     }
 
+    #[doc(alias = "get_payload_buffer")]
+    #[doc(alias = "gst_rtp_buffer_get_payload_buffer")]
+    pub fn payload_buffer(&self) -> Result<gst::Buffer, glib::BoolError> {
+        unsafe {
+            Option::<_>::from_glib_full(ffi::gst_rtp_buffer_get_payload_buffer(
+                glib::translate::mut_override(&self.rtp_buffer),
+            ))
+            .ok_or_else(|| glib::bool_error!("Failed to get payload buffer"))
+        }
+    }
+
+    pub fn buffer(&self) -> Option<&gst::BufferRef> {
+        unsafe {
+            let ptr = self.rtp_buffer.buffer;
+
+            if ptr.is_null() {
+                None
+            } else {
+                Some(gst::BufferRef::from_ptr(ptr))
+            }
+        }
+    }
+
     #[doc(alias = "get_extension")]
     pub fn is_extension(&self) -> bool {
         unsafe {
@@ -385,6 +417,34 @@ impl<'a, T> RTPBuffer<'a, T> {
             ))
         }
     }
+
+    pub unsafe fn as_ptr(&self) -> *const ffi::GstRTPBuffer {
+        &self.rtp_buffer as *const ffi::GstRTPBuffer
+    }
+
+    pub unsafe fn as_mut_ptr(&self) -> *mut ffi::GstRTPBuffer {
+        &self.rtp_buffer as *const ffi::GstRTPBuffer as *mut ffi::GstRTPBuffer
+    }
+}
+
+impl RTPBuffer<'_, ()> {
+    #[doc(alias = "gst_rtp_buffer_calc_header_len")]
+    pub fn calc_header_len(csrc_count: u8) -> u32 {
+        skip_assert_initialized!();
+        unsafe { ffi::gst_rtp_buffer_calc_header_len(csrc_count) }
+    }
+
+    #[doc(alias = "gst_rtp_buffer_calc_packet_len")]
+    pub fn calc_packet_len(payload_len: u32, pad_len: u8, csrc_count: u8) -> u32 {
+        skip_assert_initialized!();
+        unsafe { ffi::gst_rtp_buffer_calc_packet_len(payload_len, pad_len, csrc_count) }
+    }
+
+    #[doc(alias = "gst_rtp_buffer_calc_payload_len")]
+    pub fn calc_payload_len(packet_len: u32, pad_len: u8, csrc_count: u8) -> u32 {
+        skip_assert_initialized!();
+        unsafe { ffi::gst_rtp_buffer_calc_payload_len(packet_len, pad_len, csrc_count) }
+    }
 }
 
 impl<'a, T> Drop for RTPBuffer<'a, T> {
@@ -631,4 +691,14 @@ mod tests {
             assert!(!rtp_buffer.has_padding());
         }
     }
+
+    #[test]
+    fn test_calc_functions() {
+        let res = RTPBuffer::calc_header_len(0);
+        assert_eq!(res, 12);
+        let res = RTPBuffer::calc_packet_len(100, 10, 2);
+        assert_eq!(res, 130);
+        let res = RTPBuffer::calc_payload_len(100, 5, 4);
+        assert_eq!(res, 67);
+    }
 }
